@@ -337,6 +337,18 @@ def _hacksAndWorkarounds():
     if fslplatform.frozen:
         os.environ.pop('MPLCONFIGDIR', None)
 
+    # nibabel rejects NIfTI images where the
+    # quaternion vector has a length greater
+    # than 1. This is fine, as it is mandated
+    # by the NIfTI spec. But FSL is much more
+    # lenient than nibabel, and nibabel can
+    # also reject some qforms due to float32
+    # imprecision. So here we're increasing
+    # the tolerance of nibabel to strange
+    # qforms.
+    import nibabel as nib
+    nib.Nifti1Header.quaternion_threshold = -1e5
+
     # OSX sometimes sets the local environment
     # variables to non-standard values, which
     # breaks the python locale module.
