@@ -740,6 +740,8 @@ labels = TypeDict({
 
     'OverlayInfoPanel.Analyze'                  : 'ANALYZE image',
     'OverlayInfoPanel.Image'                    : 'NIFTI image',
+    'OverlayInfoPanel.Image.jsonMeta'           : 'JSON metadata',
+    'OverlayInfoPanel.Image.bidsMeta'           : 'BIDS metadata',
     'OverlayInfoPanel.FEATImage'                : 'NIFTI image '
                                                   '(FEAT analysis)',
     'OverlayInfoPanel.FEATImage.featInfo'       : 'FEAT information',
@@ -786,7 +788,7 @@ labels = TypeDict({
 
     'OverlayInfoPanel.DicomImage'               : 'NIFTI Image (from DICOM)',
     'OverlayInfoPanel.DicomImage.dicomDir'      : 'DICOM directory',
-    'OverlayInfoPanel.DicomImage.dicomInfo'     : 'DICOM information',
+    'OverlayInfoPanel.DicomImage.dicomMeta'     : 'DICOM metadata',
 
     'OverlayInfoPanel.MGHImage'                 : 'NIFTI Image (from MGH)',
     'OverlayInfoPanel.MGHImage.filename'        : 'MGH image file',
@@ -868,6 +870,7 @@ labels = TypeDict({
     'FlirtFileDialog.selectFile'          : 'Choose',
     'FlirtFileDialog.ok'                  : 'Ok',
     'FlirtFileDialog.cancel'              : 'Cancel',
+    'FlirtFileDialog.inmemory'            : 'In-memory image',
 
     'ResampleDialog.ok'            : 'Ok',
     'ResampleDialog.reset'         : 'Reset',
@@ -926,6 +929,7 @@ labels = TypeDict({
     'FileTreePanel.loadDir'    : 'Load directory',
     'FileTreePanel.customTree' : 'Load tree file',
     'FileTreePanel.save'       : 'Save notes',
+    'FileTreePanel.notes'      : 'Notes position',
     'FileListPanel.notes'      : 'Notes',
     'FileListPanel.present'    : '\u2713',
     'VariablePanel.value.none' : '<none>',
@@ -1141,6 +1145,7 @@ properties = TypeDict({
     'VectorOpts.orientFlip'      : 'L/R orientation flip',
 
     'RGBVectorOpts.interpolation' : 'Interpolation',
+    'RGBVectorOpts.unitLength'    : 'Scale vectors to unit length',
 
     'LineVectorOpts.directed'    : 'Interpret vectors as directed',
     'LineVectorOpts.lineWidth'   : 'Line width',
@@ -1334,6 +1339,9 @@ choices = TypeDict({
                                      'G'    : 'G',
                                      'B'    : 'B',
                                      'A'    : 'A'},
+
+    'FileTreePanel.notes' : {'left'  : 'Left',
+                             'right' : 'Right'}
 })
 
 
