@@ -215,7 +215,7 @@ class HistogramPanel(plotpanel.OverlayPlotPanel):
         :meth:`.PlotPanel.drawDataSeries` method.
         """
 
-        if not self or self.destroyed():
+        if not self or self.destroyed:
             return
 
         hss = self.getDataSeriesToPlot()
